import gi
gi.require_version('Gtk', '4.0')
# gi.require_version('Adw', '1')
from gi.repository import Gtk, Gio, GLib, Gdk
class MainWindow(Gtk.ApplicationWindow):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        # Things will go here

        # Set some window parameters
        self.set_default_size(800, 800)
        self.set_title('PIM Entry Form 101')

        # add boxes.
        box1 = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
        box1.set_margin_top(30)
        box1.set_margin_start(30)
        box1.set_margin_end(30)
        box1.set_spacing(10)

        self.lbl_title = Gtk.Label(label='Enter details')
        self.lbl_title.set_halign(Gtk.Align.START)
        box1.append(self.lbl_title)

        label1 = Gtk.Label(label='First name')
        label1.set_halign(Gtk.Align.START)
        box1.append(label1)

        self.entry_field1 = Gtk.Entry()
        self.entry_field1.set_max_width_chars(40)
        self.entry_field1.set_halign(Gtk.Align.START)
        box1.append(self.entry_field1)

        label2 = Gtk.Label(label='Gender')
        label2.set_halign(Gtk.Align.START)
        box1.append(label2)

        radio1 = Gtk.CheckButton(label='Male')
        radio2 = Gtk.CheckButton(label='Female')
        radio3 = Gtk.CheckButton(label='Other')
        radio2.set_group(radio1)
        radio3.set_group(radio1)

        box1.append(radio1)
        box1.append(radio2)
        box1.append(radio3)

        label3 = Gtk.Label(label='Turn on Demo Mode')
        label3.set_halign(Gtk.Align.START)
        box1.append(label3)

        switch = Gtk.Switch()
        switch.set_halign(Gtk.Align.START)
        # switch.set_active(True)  # Let's default it to on
        # self.switch.connect('state-set', self.switch_switched)  # Let's trigger a function
        box1.append(switch)

        lbl_slider = Gtk.Label(label='Pizza rating?')
        lbl_slider.set_halign(Gtk.Align.START)
        box1.append(lbl_slider)

        slider = Gtk.Scale()
        slider.set_digits(0)  # Number of decimal places to use
        slider.set_range(0, 10)
        slider.set_draw_value(True)  # Show a label with current value
        slider.set_value(5)  # Sets the current value/position
        # slider.connect('value-changed', self.slider_changed)
        box1.append(slider)

        label_agree = Gtk.Label(label='I agree to the terms')
        label_agree.set_halign(Gtk.Align.START)
        box1.append(label_agree)

        check_btn = Gtk.CheckButton(label='Agree')
        box1.append(check_btn)

        self.open_dialog = Gtk.FileChooserNative.new(title='Attach a Photo',
                                                parent=self, action=Gtk.FileChooserAction.OPEN)
        self.open_dialog.connect('response', self.open_response)

        label_filepicker = Gtk.Label(label='Attach a Photo')
        label_filepicker.set_halign(Gtk.Align.START)
        box1.append(label_filepicker)

        open_button = Gtk.Button(label='Select')
        open_button.set_icon_name('document-open-symbolic')
        open_button.connect('clicked', self.show_open_dialog)
        open_button.set_halign(Gtk.Align.START)

        box1.append(open_button)

        btn_submit = Gtk.Button(label='Submit')
        btn_submit.connect('clicked', self.respond_to_submit)
        btn_submit.set_halign(Gtk.Align.START)
        box1.append(btn_submit)

        ##############################################################################################################
        self.header = Gtk.HeaderBar()
        self.set_titlebar(self.header)

        action = Gio.SimpleAction.new('something', None)
        action.connect('activate', self.print_something)
        self.add_action(action)  # Here the action is being added to the window, but you could add it to the
        # application or an 'ActionGroup'

        # Create a new menu, containing that action
        menu = Gio.Menu.new()
        menu.append('Do Something', 'win.something')  # Or you would do app.something if you had attached the
        # action to the application
        # Create a popover
        self.popover = Gtk.PopoverMenu()  # Create a new popover menu
        self.popover.set_menu_model(menu)

        # Create a menu button
        self.hamburger = Gtk.MenuButton()
        self.hamburger.set_popover(self.popover)
        self.hamburger.set_icon_name('open-menu-symbolic')  # Give it a nice icon

        # Add menu button to the header bar
        self.header.pack_start(self.hamburger)

        # Add an about dialog *************************************************
        # Set app name
        GLib.set_application_name('My App')

        # Create an action to run a *show about dialog* function we will create
        action = Gio.SimpleAction.new('about', None)
        action.connect('activate', self.show_about)
        self.add_action(action)

        menu.append('About', 'win.about')  # Add it to the menu we created in previous section

        ##### CSS ###################################################################################################
        css_provider = Gtk.CssProvider()
        css_provider.load_from_path('/home/scott/ws/py/pygo/pygo_test1/styles/style1.css')
        Gtk.StyleContext.add_provider_for_display(Gdk.Display.get_default(), css_provider,
                                                  Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION)

        self.lbl_title.set_css_classes(['title'])

        btn_submit.set_css_classes(['button-strong'])
        open_button.set_css_classes(['button-strong'])

        self.set_css_classes(['bg-green'])

        self.set_child(box1)

    def show_open_dialog(self, button):
        self.open_dialog.show()

    def open_response(self, dialog, response):
        if response == Gtk.ResponseType.ACCEPT:
            file = dialog.get_file()
            filename = file.get_path()
            print(filename)  # Here you could handle opening or saving the file

    def print_something(self, action, param):
        print('Something!')

    def show_about(self, action, param):
        self.about = Gtk.AboutDialog()  # this seems to pre-create 2 buttons to switch pane content: About and Credits
        self.about.set_transient_for(self)  # Makes the dialog always appear in from of the parent window
        self.about.set_modal(self)  # Makes the parent window unresponsive while dialog is showing

        self.about.set_authors(['Scott D'])
        self.about.set_copyright('Copyright 2023 Scott D')
        self.about.set_license_type(Gtk.License.GPL_3_0)
        self.about.set_website('http://scottdnz.cyou')
        self.about.set_website_label('PIM App label')
        self.about.set_version('1.0')
        self.about.set_logo_icon_name('My Icon name')
        self.about.show()

    def respond_to_submit(self, button):
        print('submitted')
        print('Name: ' + self.entry_field1.get_text())
        self.close()